import { w as wrapThrowsAsync } from "./errorHandlers-N7AebTum.js";
async function loadFormbricksWebsiteSDK(apiHost) {
  if (!window.formbricks) {
    const res = await fetch(`${apiHost}/api/packages/website`);
    if (!res.ok) {
      return { ok: false, error: new Error("Failed to load Formbricks Website SDK") };
    }
    const sdkScript = await res.text();
    const scriptTag = document.createElement("script");
    scriptTag.innerHTML = sdkScript;
    document.head.appendChild(scriptTag);
    const getFormbricks = async () => new Promise((resolve, reject) => {
      const checkInterval = setInterval(() => {
        if (window.formbricks) {
          clearInterval(checkInterval);
          resolve();
        }
      }, 100);
      setTimeout(() => {
        clearInterval(checkInterval);
        reject(new Error("Formbricks Website SDK loading timed out"));
      }, 1e4);
    });
    try {
      await getFormbricks();
      return { ok: true, data: void 0 };
    } catch (error) {
      return {
        ok: false,
        error: new Error(error.message ?? "Failed to load Formbricks Website SDK")
      };
    }
  }
  return { ok: true, data: void 0 };
}
const formbricksProxyHandler = {
  get(_target, prop, _receiver) {
    return async (...args) => {
      if (!window.formbricks) {
        if (prop !== "init") {
          console.error(
            "🧱 Formbricks - Global error: You need to call formbricks.init before calling any other method"
          );
          return;
        }
        if (!args[0]) {
          console.error("🧱 Formbricks - Global error: You need to pass the apiHost as the first argument");
          return;
        }
        const { apiHost } = args[0];
        const loadSDKResult = await wrapThrowsAsync(loadFormbricksWebsiteSDK)(apiHost);
        if (!loadSDKResult.ok) {
          console.error(`🧱 Formbricks - Global error: ${loadSDKResult.error.message}`);
          return;
        }
      }
      if (window.formbricks && typeof window.formbricks[prop] !== "function") {
        console.error(
          `🧱 Formbricks - Global error: Formbricks Website SDK does not support method ${String(prop)}`
        );
        return;
      }
      try {
        return window.formbricks[prop](...args);
      } catch (error) {
        console.error(`🧱 Formbricks - Global error: Something went wrong: ${error}`);
        return;
      }
    };
  }
};
const formbricksApp = new Proxy({}, formbricksProxyHandler);
export {
  formbricksApp as default
};
//# sourceMappingURL=website.js.map
